@@ -22,7 +22,7 @@
 
 #include <mailtransport_export.h>
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 #include <KCompositeJob>
 
@@ -46,7 +46,7 @@ public:
     /**
       Deletes this transport job.
     */
-    virtual ~TransportJob();
+    ~TransportJob() override;
 
     /**
       Sets the sender of the mail.
@@ -83,7 +83,7 @@ public:
 
       @see TransportManager::schedule()
     */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     /**
       Returns the Transport object containing the mail transport settings.
